# from setuptools import setup

# setup(
# 	name="who_name",
# 	version="0.1",
# 	description="just praticse",
# 	author="idk",
# 	author_email="idk@gmail.com",
# 	packages=["who_name"]
# 	)

from setuptools import setup

setup(name='who_name',
      version='0.2',
      description='The funniest joke in the world',
      author='Flying Circus',
      author_email='flyingcircus@example.com',
      license='MIT',
      packages=['who_name'],
      zip_safe=False)
